summaryrefslogtreecommitdiffstats
path: root/kmrml/kmrml/lib/kmrml_config.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmrml/kmrml/lib/kmrml_config.h')
-rw-r--r--kmrml/kmrml/lib/kmrml_config.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmrml/kmrml/lib/kmrml_config.h b/kmrml/kmrml/lib/kmrml_config.h
index 2208030a..5a423360 100644
--- a/kmrml/kmrml/lib/kmrml_config.h
+++ b/kmrml/kmrml/lib/kmrml_config.h
@@ -19,7 +19,7 @@
#ifndef KMRML_CONFIG_H
#define KMRML_CONFIG_H
-class KConfig;
+class TDEConfig;
#include <tqstringlist.h>
#include <kurl.h>
@@ -57,7 +57,7 @@ namespace KMrml
{
public:
Config();
- Config( KConfig *config ); // does not take ownership of KConfig
+ Config( TDEConfig *config ); // does not take ownership of TDEConfig
~Config();
bool sync();
@@ -115,8 +115,8 @@ namespace KMrml
TQString m_defaultHost;
TQStringList m_hostList;
- KConfig *m_config;
- KConfig *m_ownConfig;
+ TDEConfig *m_config;
+ TDEConfig *m_ownConfig;
};
}